@@ -381,7 +381,7 @@ class FunctionDescr(object):
                nbargs < cls.minargs:
             raise BadQuery('not enough argument for function %s' % cls.__name__)
         if cls.maxargs is not None and \
-               nbargs < cls.maxargs:
+               nbargs > cls.maxargs:
             raise BadQuery('too many arguments for function %s' % cls.__name__)
     check_nbargs = classmethod(check_nbargs)
 
@@ -405,8 +405,15 @@ class AggrFunctionDescr(FunctionDescr):
 class MAX(AggrFunctionDescr): pass
 class MIN(AggrFunctionDescr): pass
 class SUM(AggrFunctionDescr): pass
+
 class COUNT(AggrFunctionDescr):
     rtype = 'Int'
+    maxargs = 2
+
+    def as_sql(self, backend, args):
+        if len(args) == 2 and args[1] == get_db_helper(backend).boolean_value(True):
+            return '%s(DISTINCT %s)' % (self.name, args[0])
+        return '%s(%s)' % (self.name, args[0])
 
 class AVG(AggrFunctionDescr):
     rtype = 'Float'
@@ -423,7 +430,7 @@ class IN(FunctionDescr):
 class LENGTH(FunctionDescr):
     rtype = 'Int'
 
-class DATE(FunctionDescr):
+class DATE(FunctionDescr): # XXX deprecates now we've CAST
     rtype = 'Date'
 
 class RANDOM(FunctionDescr):
